@@ -117,9 +117,15 @@ class ResultSet:
             alternative=0,
         )
 
-        self.wins = self._reshape_two_dim_list(sum_per_player_repetition_df["Win"])
-        self.scores = self._reshape_two_dim_list(sum_per_player_repetition_df["Score"])
-        self.normalised_scores = self._reshape_two_dim_list(normalised_scores_series)
+        self.wins = self._reshape_two_dim_list(
+            sum_per_player_repetition_df["Win"]
+        )
+        self.scores = self._reshape_two_dim_list(
+            sum_per_player_repetition_df["Score"]
+        )
+        self.normalised_scores = self._reshape_two_dim_list(
+            normalised_scores_series
+        )
 
         self.cooperation = self._build_cooperation(
             sum_per_player_opponent_df["Cooperation count"]
@@ -132,7 +138,9 @@ class ResultSet:
         self.state_distribution = self._build_state_distribution(
             sum_per_player_opponent_df[columns]
         )
-        self.normalised_state_distribution = self._build_normalised_state_distribution()
+        self.normalised_state_distribution = (
+            self._build_normalised_state_distribution()
+        )
 
         columns = [
             "CC to C count",
@@ -144,8 +152,10 @@ class ResultSet:
             "DD to C count",
             "DD to D count",
         ]
-        self.state_to_action_distribution = self._build_state_to_action_distribution(
-            sum_per_player_opponent_df[columns]
+        self.state_to_action_distribution = (
+            self._build_state_to_action_distribution(
+                sum_per_player_opponent_df[columns]
+            )
         )
         self.normalised_state_to_action_distribution = (
             self._build_normalised_state_to_action_distribution()
@@ -166,7 +176,9 @@ class ResultSet:
         self.ranked_names = self._build_ranked_names()
 
         self.payoff_matrix = self._build_summary_matrix(self.payoffs)
-        self.payoff_stddevs = self._build_summary_matrix(self.payoffs, func=np.std)
+        self.payoff_stddevs = self._build_summary_matrix(
+            self.payoffs, func=np.std
+        )
 
         self.payoff_diffs_means = self._build_payoff_diffs_means()
         self.cooperating_rating = self._build_cooperating_rating()
@@ -266,7 +278,9 @@ class ResultSet:
                     # interactions.
                     row.append(0)
                 else:
-                    row.append(good_partner_dict.get((player_index, opponent_index), 0))
+                    row.append(
+                        good_partner_dict.get((player_index, opponent_index), 0)
+                    )
             good_partner_matrix.append(row)
         return good_partner_matrix
 
@@ -334,13 +348,17 @@ class ResultSet:
             for counter in player:
                 total = sum(counter.values())
                 counters.append(
-                    Counter({key: value / total for key, value in counter.items()})
+                    Counter(
+                        {key: value / total for key, value in counter.items()}
+                    )
                 )
             normalised_state_distribution.append(counters)
         return normalised_state_distribution
 
     @update_progress_bar
-    def _build_state_to_action_distribution(self, state_to_action_distribution_series):
+    def _build_state_to_action_distribution(
+        self, state_to_action_distribution_series
+    ):
         state_to_action_key_map = {
             "CC to C count": ((C, C), C),
             "CC to D count": ((C, C), D),
@@ -396,8 +414,12 @@ class ResultSet:
         return normalised_state_to_action_distribution
 
     @update_progress_bar
-    def _build_initial_cooperation_count(self, initial_cooperation_count_series):
-        initial_cooperation_count_dict = initial_cooperation_count_series.to_dict()
+    def _build_initial_cooperation_count(
+        self, initial_cooperation_count_series
+    ):
+        initial_cooperation_count_dict = (
+            initial_cooperation_count_series.to_dict()
+        )
         initial_cooperation_count = [
             initial_cooperation_count_dict.get(player_index, 0)
             for player_index in range(self.num_players)
@@ -427,7 +449,8 @@ class ResultSet:
             warnings.simplefilter("ignore")
             initial_cooperation_rate = list(
                 np.nan_to_num(
-                    np.array(self.initial_cooperation_count) / interactions_array
+                    np.array(self.initial_cooperation_count)
+                    / interactions_array
                 )
             )
             return initial_cooperation_rate
@@ -453,7 +476,9 @@ class ResultSet:
         The eigenmoses rating as defined in:
         http://www.scottaaronson.com/morality.pdf
         """
-        eigenvector, eigenvalue = eigen.principal_eigenvector(self.vengeful_cooperation)
+        eigenvector, eigenvalue = eigen.principal_eigenvector(
+            self.vengeful_cooperation
+        )
 
         return eigenvector.tolist()
 
@@ -577,7 +602,9 @@ class ResultSet:
         ]
         sum_per_player_opponent_task = df.groupby(groups)[columns].sum()
 
-        ignore_self_interactions_task = df["Player index"] != df["Opponent index"]
+        ignore_self_interactions_task = (
+            df["Player index"] != df["Opponent index"]
+        )
         adf = df[ignore_self_interactions_task]
 
         groups = ["Player index", "Repetition"]
@@ -591,7 +618,9 @@ class ResultSet:
         groups = ["Player index"]
         column = "Initial cooperation"
         initial_cooperation_count_task = adf.groupby(groups)[column].sum()
-        interactions_count_task = adf.groupby("Player index")["Player index"].count()
+        interactions_count_task = adf.groupby("Player index")[
+            "Player index"
+        ].count()
 
         return (
             mean_per_reps_player_opponent_task,
@@ -642,8 +671,12 @@ class ResultSet:
                 self.cooperating_rating == other.cooperating_rating,
                 self.good_partner_matrix == other.good_partner_matrix,
                 self.good_partner_rating == other.good_partner_rating,
-                list_equal_with_nans(self.eigenmoses_rating, other.eigenmoses_rating),
-                list_equal_with_nans(self.eigenjesus_rating, other.eigenjesus_rating),
+                list_equal_with_nans(
+                    self.eigenmoses_rating, other.eigenmoses_rating
+                ),
+                list_equal_with_nans(
+                    self.eigenjesus_rating, other.eigenjesus_rating
+                ),
             ]
         )
 
@@ -713,7 +746,9 @@ class ResultSet:
             rates = []
             for state in states:
                 counts = [
-                    counter[(state, C)] for counter in player if counter[(state, C)] > 0
+                    counter[(state, C)]
+                    for counter in player
+                    if counter[(state, C)] > 0
                 ]
 
                 if len(counts) > 0:
@@ -736,7 +771,9 @@ class ResultSet:
 
         summary_data = []
         for rank, i in enumerate(self.ranking):
-            data = list(summary_measures[i]) + state_prob[i] + state_to_C_prob[i]
+            data = (
+                list(summary_measures[i]) + state_prob[i] + state_to_C_prob[i]
+            )
             summary_data.append(self.player(rank, *data))
 
         return summary_data
