@@ -92,6 +92,7 @@ from .finite_state_machines import (
     TF2,
     TF3,
     EvolvedFSM4,
+    EvolvedFSM6,
     EvolvedFSM16,
     EvolvedFSM16Noise05,
     Fortress3,
@@ -119,7 +120,6 @@ from .gambler import (
     ZDMem2,
 )
 from .gambler import EvolvableGambler, Gambler  # pylint: disable=unused-import
-from .geller import Geller, GellerCooperator, GellerDefector
 from .gobymajority import (
     GoByMajority,
     GoByMajority5,
@@ -135,6 +135,7 @@ from .gobymajority import (
 from .gradualkiller import GradualKiller
 from .grudger import (
     Aggravater,
+    Capri,
     EasyGo,
     ForgetfulGrudger,
     GeneralSoftGrudger,
@@ -142,6 +143,7 @@ from .grudger import (
     GrudgerAlternator,
     OppositeGrudger,
     SoftGrudger,
+    SpitefulCC,
 )
 from .grumpy import Grumpy
 from .handshake import Handshake
@@ -188,8 +190,6 @@ from .memoryone import (  # pylint: disable=unused-import
 from .memorytwo import AON2, MEM2, DelayedAON1
 from .memorytwo import MemoryTwoPlayer  # pylint: disable=unused-import
 
-from .mindcontrol import MindBender, MindController, MindWarper
-from .mindreader import MindReader, MirrorMindReader, ProtectedMindReader
 from .mutual import Desperate, Hopeless, Willing
 from .negation import Negation
 from .oncebitten import FoolMeOnce, ForgetfulFoolMeOnce, OnceBitten
@@ -304,6 +304,7 @@ all_strategies = [
     Bully,
     BushMosteller,
     Calculator,
+    Capri,
     CautiousQLearner,
     CollectiveStrategy,
     ContriteTitForTat,
@@ -336,6 +337,7 @@ all_strategies = [
     EvolvedFSM16,
     EvolvedFSM16Noise05,
     EvolvedFSM4,
+    EvolvedFSM6,
     EvolvedHMM5,
     EvolvedLookerUp1_1_1,
     EvolvedLookerUp2_2_2,
@@ -360,9 +362,6 @@ all_strategies = [
     Fortress3,
     Fortress4,
     GTFT,
-    Geller,
-    GellerCooperator,
-    GellerDefector,
     GeneralSoftGrudger,
     GoByMajority,
     GoByMajority10,
@@ -396,11 +395,6 @@ all_strategies = [
     MEM2,
     MathConstantHunter,
     Michaelos,
-    MindBender,
-    MindController,
-    MindReader,
-    MindWarper,
-    MirrorMindReader,
     NTitsForMTats,
     NaiveProber,
     Negation,
@@ -419,7 +413,6 @@ all_strategies = [
     Prober2,
     Prober3,
     Prober4,
-    ProtectedMindReader,
     Pun1,
     Punisher,
     Raider,
@@ -467,6 +460,7 @@ all_strategies = [
     SolutionB1,
     SolutionB5,
     SpitefulTitForTat,
+    SpitefulCC,
     Stalker,
     StochasticCooperator,
     StochasticWSLS,
