@@ -66,7 +66,7 @@ class FirstByDavis(Player):
         opponent ever plays D."""
         if len(self.history) < self._rounds_to_cooperate:
             return C
-        if opponent.defections > 0:  # Implement Grudger
+        if opponent.defections > 0:  #  Implement Grudger
             return D
         return C
 
@@ -245,6 +245,7 @@ class FirstByDowning(Player):
         self.number_opponent_cooperations_in_response_to_D = 0
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         round_number = len(self.history) + 1
 
         if round_number == 1:
@@ -262,12 +263,14 @@ class FirstByDowning(Player):
         # Adding 1 to cooperations for assumption that first opponent move
         # being a response to a cooperation. See docstring for more
         # information.
-        alpha = (self.number_opponent_cooperations_in_response_to_C /
-                 (self.cooperations + 1))
+        alpha = self.number_opponent_cooperations_in_response_to_C / (
+            self.cooperations + 1
+        )
         # Adding 2 to defections on the assumption that the first two
         # moves are defections, which may not be true in a noisy match
-        beta = (self.number_opponent_cooperations_in_response_to_D /
-                 max(self.defections, 2))
+        beta = self.number_opponent_cooperations_in_response_to_D / max(
+            self.defections, 2
+        )
 
         R, P, S, T = self.match_attributes["game"].RPST()
         expected_value_of_cooperating = alpha * R + (1 - alpha) * S
@@ -345,6 +348,7 @@ class FirstByFeld(Player):
         return max(self._start_coop_prob + slope * rounds, self._end_coop_prob)
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         if not opponent.history:
             return C
         if opponent.history[-1] == D:
@@ -430,25 +434,34 @@ class FirstByGraaskamp(Player):
 
         # Check if opponent plays randomly, if so, defect for the rest of the game
         p_value = chisquare([opponent.cooperations, opponent.defections]).pvalue
-        self.opponent_is_random = (p_value >= self.alpha) or self.opponent_is_random
+        self.opponent_is_random = (
+            p_value >= self.alpha
+        ) or self.opponent_is_random
 
         if self.opponent_is_random:
             return D
-        if all(
-            opponent.history[i] == self.history[i - 1]
-            for i in range(1, len(self.history))
-        ) or opponent.history == self.history:
+        if (
+            all(
+                opponent.history[i] == self.history[i - 1]
+                for i in range(1, len(self.history))
+            )
+            or opponent.history == self.history
+        ):
             # Check if opponent plays Tit for Tat or a clone of itself.
             if opponent.history[-1] == D:
                 return D
             return C
 
         if self.next_random_defection_turn is None:
-            self.next_random_defection_turn = self._random.randint(5, 15) + len(self.history)
+            self.next_random_defection_turn = self._random.randint(5, 15) + len(
+                self.history
+            )
 
         if len(self.history) == self.next_random_defection_turn:
             # resample the next defection turn
-            self.next_random_defection_turn = self._random.randint(5, 15) + len(self.history)
+            self.next_random_defection_turn = self._random.randint(5, 15) + len(
+                self.history
+            )
             return D
         return C
 
@@ -480,6 +493,7 @@ class FirstByGrofman(Player):
     }
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         if len(self.history) == 0 or self.history[-1] == opponent.history[-1]:
             return C
         return self._random.random_choice(2 / 7)
@@ -580,7 +594,27 @@ class FirstByNydegger(Player):
     }
 
     def __init__(self) -> None:
-        self.As = [1, 6, 7, 17, 22, 23, 26, 29, 30, 31, 33, 38, 39, 45, 49, 54, 55, 58, 61]
+        self.As = [
+            1,
+            6,
+            7,
+            17,
+            22,
+            23,
+            26,
+            29,
+            30,
+            31,
+            33,
+            38,
+            39,
+            45,
+            49,
+            54,
+            55,
+            58,
+            61,
+        ]
         self.score_map = {(C, C): 0, (C, D): 2, (D, C): 1, (D, D): 3}
         super().__init__()
 
@@ -599,6 +633,7 @@ class FirstByNydegger(Player):
         return a
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         if len(self.history) == 0:
             return C
         if len(self.history) == 1:
@@ -610,7 +645,9 @@ class FirstByNydegger(Player):
             else:
                 # TFT
                 return D if opponent.history[-1] == D else C
-        A = self.score_history(self.history[-3:], opponent.history[-3:], self.score_map)
+        A = self.score_history(
+            self.history[-3:], opponent.history[-3:], self.score_map
+        )
         if A in self.As:
             return D
         return C
@@ -680,6 +717,7 @@ class FirstByShubik(Player):
                 self.is_retaliating = False
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         if not opponent.history:
             return C
 
@@ -740,6 +778,7 @@ class FirstByTullock(Player):
         self._rounds_to_cooperate = 11
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         if len(self.history) < self._rounds_to_cooperate:
             return C
         rounds = self._rounds_to_cooperate - 1
@@ -784,6 +823,7 @@ class FirstByAnonymous(Player):
     }
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         r = self._random.uniform(3, 7) / 10
         return self._random.random_choice(r)
 
@@ -839,6 +879,7 @@ class FirstBySteinAndRapoport(Player):
         self.opponent_is_random = False
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         round_number = len(self.history) + 1
 
         # First 4 moves
@@ -849,7 +890,9 @@ class FirstBySteinAndRapoport(Player):
             return opponent.history[-1]
 
         if round_number % 15 == 0:
-            p_value = chisquare([opponent.cooperations, opponent.defections]).pvalue
+            p_value = chisquare(
+                [opponent.cooperations, opponent.defections]
+            ).pvalue
             self.opponent_is_random = p_value >= self.alpha
 
         if self.opponent_is_random:
@@ -949,6 +992,7 @@ class FirstByTidemanAndChieruzzi(Player):
         self.opponent_score += scores[1]
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         if not opponent.history:
             return C
 
@@ -982,8 +1026,10 @@ class FirstByTidemanAndChieruzzi(Player):
                 std_deviation = (N ** (1 / 2)) / 2
                 lower = N / 2 - 3 * std_deviation
                 upper = N / 2 + 3 * std_deviation
-                if (self.remembered_number_of_opponent_defectioons <= lower or
-                    self.remembered_number_of_opponent_defectioons >= upper):
+                if (
+                    self.remembered_number_of_opponent_defectioons <= lower
+                    or self.remembered_number_of_opponent_defectioons >= upper
+                ):
                     # Opponent deserves a fresh start
                     self.last_fresh_start = current_round
                     self._fresh_start()
