@@ -41,6 +41,7 @@ class SecondByChampion(Player):
     }
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         current_round = len(self.history)
         # Cooperate for the first 10 turns
         if current_round == 0:
@@ -84,6 +85,7 @@ class SecondByEatherley(Player):
     }
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         # Cooperate on the first move
         if not len(opponent.history):
             return C
@@ -127,6 +129,7 @@ class SecondByTester(Player):
         self.is_TFT = False
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         # Defect on the first move
         if not opponent.history:
             return D
@@ -180,6 +183,7 @@ class SecondByGladstein(Player):
         self.patsy = True
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         # Defect on the first move
         if not self.history:
             return D
@@ -327,8 +331,12 @@ class SecondByTranquilizer(Player):
         self.opponent_consecutive_defections = 0  # equal to S variable
         self.one_turn_after_good_defection_ratio = 5  # equal to AD variable
         self.two_turns_after_good_defection_ratio = 0  # equal to NO variable
-        self.one_turn_after_good_defection_ratio_count = 1  # equal to AK variable
-        self.two_turns_after_good_defection_ratio_count = 1  # equal to NK variable
+        self.one_turn_after_good_defection_ratio_count = (
+            1  # equal to AK variable
+        )
+        self.two_turns_after_good_defection_ratio_count = (
+            1  # equal to NK variable
+        )
         # All above variables correspond to those in original Fotran Code
         self.dict = {C: 0, D: 1}
 
@@ -353,7 +361,12 @@ class SecondByTranquilizer(Player):
                 )
                 + (3 - (3 * self.dict[opponent.history[-1]]))
                 + (2 * self.dict[self.history[-1]])
-                - ((self.dict[opponent.history[-1]] * self.dict[self.history[-1]]))
+                - (
+                    (
+                        self.dict[opponent.history[-1]]
+                        * self.dict[self.history[-1]]
+                    )
+                )
             ) / (self.two_turns_after_good_defection_ratio_count + 1)
             self.two_turns_after_good_defection_ratio_count += 1
         elif self.num_turns_after_good_defection == 1:
@@ -365,11 +378,15 @@ class SecondByTranquilizer(Player):
                 )
                 + (3 - (3 * self.dict[opponent.history[-1]]))
                 + (2 * self.dict[self.history[-1]])
-                - (self.dict[opponent.history[-1]] * self.dict[self.history[-1]])
+                - (
+                    self.dict[opponent.history[-1]]
+                    * self.dict[self.history[-1]]
+                )
             ) / (self.one_turn_after_good_defection_ratio_count + 1)
             self.one_turn_after_good_defection_ratio_count += 1
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
 
         if not self.history:
             return C
@@ -402,7 +419,10 @@ class SecondByTranquilizer(Player):
             return D
         if (current_score[0] / ((len(self.history)) + 1)) >= 1.75:
             probability = (
-                (0.25 + ((opponent.cooperations + 1) / ((len(self.history)) + 1)))
+                (
+                    0.25
+                    + ((opponent.cooperations + 1) / ((len(self.history)) + 1))
+                )
                 - (self.opponent_consecutive_defections * 0.25)
                 + ((current_score[0] - current_score[1]) / 100)
                 + (4 / ((len(self.history)) + 1))
@@ -452,6 +472,7 @@ class SecondByGrofman(Player):
     }
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         # Cooperate on the first two moves
         if len(self.history) < 2:
             return C
@@ -516,9 +537,15 @@ class SecondByKluepfel(Player):
 
     def __init__(self):
         super().__init__()
-        self.cd_counts, self.dd_counts, self.dc_counts, self.cc_counts = 0, 0, 0, 0
+        self.cd_counts, self.dd_counts, self.dc_counts, self.cc_counts = (
+            0,
+            0,
+            0,
+            0,
+        )
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         # First update the response matrix.
         if len(self.history) >= 2:
             if self.history[-2] == D:
@@ -534,7 +561,9 @@ class SecondByKluepfel(Player):
 
         # Check for randomness
         if len(self.history) > 26:
-            if self.cd_counts >= (self.cd_counts + self.dd_counts) / 2 - 0.75 * np.sqrt(
+            if self.cd_counts >= (
+                self.cd_counts + self.dd_counts
+            ) / 2 - 0.75 * np.sqrt(
                 self.cd_counts + self.dd_counts
             ) and self.dc_counts >= (
                 self.dc_counts + self.cc_counts
@@ -648,6 +677,7 @@ class SecondByBorufsen(Player):
         return D
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         turn = len(self.history) + 1
 
         if turn == 1:
@@ -675,7 +705,7 @@ class SecondByBorufsen(Player):
                 self.mode = "Defect"
 
             # Check for a random strategy
-            if (coops >= 8 and coops <= 17) and self.cc_counts / coops < 0.7:
+            if (8 <= coops <= 17) and self.cc_counts / coops < 0.7:
                 self.mode = "Defect"
 
             self.cd_counts, self.cc_counts = 0, 0
@@ -761,6 +791,7 @@ class SecondByCave(Player):
     }
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         turn = len(self.history) + 1
         if turn == 1:
             return C
@@ -811,6 +842,7 @@ class SecondByWmAdams(Player):
     }
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         if len(self.history) <= 1:
             return C
         number_defects = opponent.defections
@@ -867,6 +899,7 @@ class SecondByGraaskampKatzen(Player):
         self.own_score += game.score(last_round)[0]
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         if self.mode == "Defect":
             return D
 
@@ -956,6 +989,7 @@ class SecondByWeiner(Player):
         return to_return
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         if len(opponent.history) == 0:
             return C
 
@@ -969,7 +1003,10 @@ class SecondByWeiner(Player):
         if self.forgive_flag:
             self.forgive_flag = False
             self.defect_padding = 0
-            if self.grudge < len(self.history) + 1 and opponent.history[-1] == D:
+            if (
+                self.grudge < len(self.history) + 1
+                and opponent.history[-1] == D
+            ):
                 # Then override
                 self.grudge += 20
                 return self.try_return(C)
@@ -1095,7 +1132,9 @@ class SecondByHarrington(Player):
         self.mode = "Normal"
         self.recorded_defects = 0  # Count opponent defects after turn 1
         self.exit_defect_meter = 0  # When >= 11, then exit defect mode.
-        self.coops_in_first_36 = None  # On turn 37, count cooperations in first 36
+        self.coops_in_first_36 = (
+            None  # On turn 37, count cooperations in first 36
+        )
         self.was_defective = False  # Previously in Defect mode
 
         self.prob = 0.25  # After turn 37, probability that we'll defect
@@ -1105,7 +1144,9 @@ class SecondByHarrington(Player):
         self.more_coop = 0  # This schedules cooperation for future turns
         # Initial last_generous_n_turns_ago to 3 because this counts up and
         # triggers a strategy change at 2.
-        self.last_generous_n_turns_ago = 3  # How many tuns ago was a "generous" move
+        self.last_generous_n_turns_ago = (
+            3  # How many tuns ago was a "generous" move
+        )
         self.burned = False
 
         self.defect_streak = 0
@@ -1114,7 +1155,9 @@ class SecondByHarrington(Player):
             0,
         ]  # Counters that get (almost) alternatively incremented.
         self.parity_bit = 0  # Which parity_streak to increment
-        self.parity_limit = 5  # When a parity streak hits this limit, alter strategy.
+        self.parity_limit = (
+            5  # When a parity streak hits this limit, alter strategy.
+        )
         self.parity_hits = 0  # Counts how many times a parity_limit was hit.
         # After hitting parity_hits 8 times, lower parity_limit to 3.
 
@@ -1153,7 +1196,9 @@ class SecondByHarrington(Player):
         denom = turn - 2
 
         expected_matrix = (
-            np.outer(self.move_history.sum(axis=1), self.move_history.sum(axis=0))
+            np.outer(
+                self.move_history.sum(axis=1), self.move_history.sum(axis=0)
+            )
             / denom
         )
 
@@ -1162,7 +1207,9 @@ class SecondByHarrington(Player):
             for j in range(2):
                 expect = expected_matrix[i, j]
                 if expect > 1.0:
-                    chi_squared += (expect - self.move_history[i, j]) ** 2 / expect
+                    chi_squared += (
+                        expect - self.move_history[i, j]
+                    ) ** 2 / expect
 
         return chi_squared
 
@@ -1184,7 +1231,10 @@ class SecondByHarrington(Player):
 
         if self.move_history[0, 0] / denom >= 0.8:
             return False
-        if self.recorded_defects / denom < 0.25 or self.recorded_defects / denom > 0.75:
+        if (
+            self.recorded_defects / denom < 0.25
+            or self.recorded_defects / denom > 0.75
+        ):
             return False
 
         if self.calculate_chi_squared(turn) > 3:
@@ -1224,6 +1274,7 @@ class SecondByHarrington(Player):
             return True
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         turn = len(self.history) + 1
 
         if turn == 1:
@@ -1276,7 +1327,11 @@ class SecondByHarrington(Player):
 
         # Only enter Fair-weather mode if the opponent Cooperated the first 37
         # turns then Defected on the 38th.
-        if turn == 38 and opponent.history[-1] == D and opponent.cooperations == 36:
+        if (
+            turn == 38
+            and opponent.history[-1] == D
+            and opponent.cooperations == 36
+        ):
             self.mode = "Fair-weather"
             return self.try_return(to_return=C, lower_flags=False)
 
@@ -1297,7 +1352,9 @@ class SecondByHarrington(Player):
             self.parity_streak[
                 self.parity_bit
             ] = 0  # Reset `parity_streak` when we hit the limit.
-            self.parity_hits += 1  # Keep track of how many times we hit the limit.
+            self.parity_hits += (
+                1  # Keep track of how many times we hit the limit.
+            )
             if self.parity_hits >= 8:  # After 8 times, lower the limit.
                 self.parity_limit = 3
             return self.try_return(
@@ -1389,6 +1446,7 @@ class SecondByTidemanAndChieruzzi(Player):
         self.opponent_score += scores[1]
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         current_round = len(self.history) + 1
 
         if current_round == 1:
@@ -1463,6 +1521,7 @@ class SecondByGetzler(Player):
         self.flack = 0.0  # The relative untrustworthiness of opponent
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         if not opponent.history:
             return C
 
@@ -1521,7 +1580,9 @@ class SecondByLeyvraz(Player):
                 recent_history[-go_back] = opponent.history[-go_back]
 
         return self._random.random_choice(
-            self.prob_coop[(recent_history[-3], recent_history[-2], recent_history[-1])]
+            self.prob_coop[
+                (recent_history[-3], recent_history[-2], recent_history[-1])
+            ]
         )
 
 
@@ -1704,7 +1765,10 @@ class SecondByRichardHufford(Player):
             else:
                 self.def_after_ab_count += 1
             self.streak_needed = (
-                np.floor(20.0 * self.def_after_ab_count / self.coop_after_ab_count) + 1
+                np.floor(
+                    20.0 * self.def_after_ab_count / self.coop_after_ab_count
+                )
+                + 1
             )
             self.current_streak = 0
             return C
@@ -1784,7 +1848,7 @@ class SecondByYamachi(Player):
         # If so, then override
         if turn > 40:
             portion_defect = (opp_def + 0.5) / turn
-            if 0.45 < portion_defect and portion_defect < 0.55:
+            if 0.45 < portion_defect < 0.55:
                 return D
 
         return to_return
@@ -1804,7 +1868,9 @@ class SecondByYamachi(Player):
 
         # Update history
         if turn >= 3:
-            self.count_them_us_them[(them_three_ago, us_two_ago, them_two_ago)] += 1
+            self.count_them_us_them[
+                (them_three_ago, us_two_ago, them_two_ago)
+            ] += 1
 
         if (
             self.count_them_us_them[(them_two_ago, us_last, C)]
@@ -1866,7 +1932,9 @@ class SecondByColbert(FSMPlayer):
             (10, D, 7, C),
         )
 
-        super().__init__(transitions=transitions, initial_state=0, initial_action=C)
+        super().__init__(
+            transitions=transitions, initial_state=0, initial_action=C
+        )
 
 
 class SecondByMikkelson(FSMPlayer):
@@ -2100,6 +2168,8 @@ class SecondByAppold(Player):
 
         # Calculate the probability that the opponent cooperated last turn given
         # what we know two turns ago.
-        prob_coop = self.opp_c_after_x[us_two_turns_ago] / self.total_num_of_x[
-            us_two_turns_ago]
+        prob_coop = (
+            self.opp_c_after_x[us_two_turns_ago]
+            / self.total_num_of_x[us_two_turns_ago]
+        )
         return self._random.random_choice(prob_coop)
