@@ -37,10 +37,12 @@ class Calculator(Player):
         self.joss_instance.set_seed(seed)
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         turn = len(self.history)
         if turn > 0:
-            self.joss_instance.history.append(self.history[-1],
-                                              opponent.history[-1])
+            self.joss_instance.history.append(
+                self.history[-1], opponent.history[-1]
+            )
         if turn == 20:
             self.cycle = detect_cycle(opponent.history)
             return self.extended_strategy(opponent)
