@@ -45,6 +45,7 @@ class AntiCycler(Player):
         return [C, D, D]
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         while self.first_three:
             return self.first_three.pop(0)
         if self.cycle_counter < self.cycle_length:
@@ -91,6 +92,7 @@ class Cycler(Player):
         self.set_cycle(cycle=cycle)
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         return next(self.cycle_iter)
 
     def set_cycle(self, cycle: str):
@@ -111,23 +113,25 @@ class EvolvableCycler(Cycler, EvolvablePlayer):
         cycle_length: int = None,
         mutation_probability: float = 0.2,
         mutation_potency: int = 1,
-        seed: int = None
+        seed: int = None,
     ) -> None:
         EvolvablePlayer.__init__(self, seed=seed)
         cycle, cycle_length = self._normalize_parameters(cycle, cycle_length)
         Cycler.__init__(self, cycle=cycle)
         # Overwrite init_kwargs in the case that we generated a new cycle from cycle_length
-        self.overwrite_init_kwargs(
-            cycle=cycle,
-            cycle_length=cycle_length)
+        self.overwrite_init_kwargs(cycle=cycle, cycle_length=cycle_length)
         self.mutation_probability = mutation_probability
         self.mutation_potency = mutation_potency
 
-    def _normalize_parameters(self, cycle=None, cycle_length=None) -> Tuple[str, int]:
+    def _normalize_parameters(
+        self, cycle=None, cycle_length=None
+    ) -> Tuple[str, int]:
         """Compute other parameters from those that may be missing, to ensure proper cloning."""
         if not cycle:
             if not cycle_length:
-                raise InsufficientParametersError("Insufficient Parameters to instantiate EvolvableCycler")
+                raise InsufficientParametersError(
+                    "Insufficient Parameters to instantiate EvolvableCycler"
+                )
             cycle = self._generate_random_cycle(cycle_length)
         cycle_length = len(cycle)
         return cycle, cycle_length
@@ -136,7 +140,9 @@ class EvolvableCycler(Cycler, EvolvablePlayer):
         """
         Generate a sequence of random moves
         """
-        return actions_to_str(self._random.choice(actions) for _ in range(cycle_length))
+        return actions_to_str(
+            self._random.choice(actions) for _ in range(cycle_length)
+        )
 
     def mutate(self) -> EvolvablePlayer:
         """
@@ -145,8 +151,12 @@ class EvolvableCycler(Cycler, EvolvablePlayer):
         if self._random.random() <= self.mutation_probability:
             mutated_sequence = list(str_to_actions(self.cycle))
             for _ in range(self.mutation_potency):
-                index_to_change = self._random.randint(0, len(mutated_sequence) - 1)
-                mutated_sequence[index_to_change] = mutated_sequence[index_to_change].flip()
+                index_to_change = self._random.randint(
+                    0, len(mutated_sequence) - 1
+                )
+                mutated_sequence[index_to_change] = mutated_sequence[
+                    index_to_change
+                ].flip()
             cycle = actions_to_str(mutated_sequence)
         else:
             cycle = self.cycle
@@ -158,7 +168,9 @@ class EvolvableCycler(Cycler, EvolvablePlayer):
         Creates and returns a new Player instance with a single crossover point.
         """
         if other.__class__ != self.__class__:
-            raise TypeError("Crossover must be between the same player classes.")
+            raise TypeError(
+                "Crossover must be between the same player classes."
+            )
         cycle_list = crossover_lists(self.cycle, other.cycle, self._random)
         cycle = "".join(cycle_list)
         cycle, _ = self._normalize_parameters(cycle)
