@@ -54,12 +54,8 @@ class Darwin(Player):
     def receive_match_attributes(self):
         self.outcomes = self.match_attributes["game"].scores
 
-    @staticmethod
-    def foil_strategy_inspection() -> Action:
-        """Foils _strategy_utils.inspect_strategy and _strategy_utils.look_ahead"""
-        return C
-
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         trial = len(self.history)
 
         if trial > 0:
@@ -80,12 +76,12 @@ class Darwin(Player):
         return current
 
     def reset(self):
-        """ Reset instance properties. """
+        """Reset instance properties."""
         super().reset()
         Darwin.genome[0] = C  # Ensure initial Cooperate
 
     def mutate(self, outcome: tuple, trial: int) -> None:
-        """ Select response according to outcome. """
+        """Select response according to outcome."""
         if outcome[0] < 3 and (len(Darwin.genome) >= trial):
             self.response = D if Darwin.genome[trial - 1] == C else C
 
