@@ -26,6 +26,7 @@ class Defector(Player):
 
     @staticmethod
     def strategy(opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         return D
 
 
@@ -54,6 +55,9 @@ class TrickyDefector(Player):
         Defect if opponent has cooperated at least once in the past and has
         defected for the last 3 turns in a row.
         """
-        if opponent.history.cooperations > 0 and opponent.history[-3:] == [D] * 3:
+        if (
+            opponent.history.cooperations > 0
+            and opponent.history[-3:] == [D] * 3
+        ):
             return C
         return D
