@@ -51,7 +51,9 @@ class Punisher(Player):
             return D
 
         elif D in opponent.history[-1:]:
-            self.mem_length = (opponent.defections * 20) // len(opponent.history)
+            self.mem_length = (opponent.defections * 20) // len(
+                opponent.history
+            )
             self.grudged = True
             return D
 
@@ -101,7 +103,9 @@ class InversePunisher(Player):
             self.grudge_memory += 1
             return D
         elif D in opponent.history[-1:]:
-            self.mem_length = (opponent.cooperations * 20) // len(opponent.history)
+            self.mem_length = (opponent.cooperations * 20) // len(
+                opponent.history
+            )
             if self.mem_length == 0:
                 self.mem_length += 1
             self.grudged = True
@@ -131,6 +135,7 @@ class LevelPunisher(Player):
     }
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         if len(opponent.history) < 10:
             return C
         elif opponent.defections / len(opponent.history) > 0.2:
@@ -161,6 +166,7 @@ class TrickyLevelPunisher(Player):
     }
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         if len(opponent.history) == 0:
             return C
         if len(opponent.history) < 10:
