@@ -34,7 +34,7 @@ class SequencePlayer(Player):
             return C
 
     def strategy(self, opponent: Player) -> Action:
-        # Iterate through the sequence and apply the meta strategy
+        """Iterate through the sequence and apply the meta strategy."""
         for s in self.sequence_generator:
             return self.meta_strategy(s)
 
@@ -80,7 +80,7 @@ class ThueMorse(SequencePlayer):
 
 
 class ThueMorseInverse(ThueMorse):
-    """ A player who plays the inverse of the Thue-Morse sequence.
+    """A player who plays the inverse of the Thue-Morse sequence.
 
     Names:
 
