@@ -22,7 +22,7 @@ class ShortMem(Player):
 
     name = "ShortMem"
     classifier = {
-        "memory_depth": float('inf'),
+        "memory_depth": float("inf"),
         "stochastic": False,
         "long_run_time": False,
         "inspects_source": False,
@@ -32,6 +32,7 @@ class ShortMem(Player):
 
     @staticmethod
     def strategy(opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         if len(opponent.history) <= 10:
             return C
 
