@@ -1,6 +1,9 @@
 from axelrod.action import Action, actions_to_str
 from axelrod.player import Player
-from axelrod.strategy_transformers import FinalTransformer, TrackHistoryTransformer
+from axelrod.strategy_transformers import (
+    FinalTransformer,
+    TrackHistoryTransformer,
+)
 
 C, D = Action.C, Action.D
 
@@ -71,6 +74,7 @@ class TitFor2Tats(Player):
 
     @staticmethod
     def strategy(opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         return D if opponent.history[-2:] == [D, D] else C
 
 
@@ -95,6 +99,7 @@ class TwoTitsForTat(Player):
 
     @staticmethod
     def strategy(opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         return D if D in opponent.history[-2:] else C
 
 
@@ -122,13 +127,16 @@ class DynamicTwoTitsForTat(Player):
     }
 
     def strategy(self, opponent):
+        """Actual strategy definition that determines player's action."""
         # First move
         if not opponent.history:
             # Make sure we cooperate first turn
             return C
         if D in opponent.history[-2:]:
             # Probability of cooperating regardless
-            return self._random.random_choice(opponent.cooperations / len(opponent.history))
+            return self._random.random_choice(
+                opponent.cooperations / len(opponent.history)
+            )
         else:
             return C
 
@@ -158,6 +166,7 @@ class Bully(Player):
 
     @staticmethod
     def strategy(opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         return C if opponent.history[-1:] == [D] else D
 
 
@@ -180,6 +189,7 @@ class SneakyTitForTat(Player):
     }
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         if len(self.history) < 2:
             return C
         if D not in opponent.history:
@@ -210,6 +220,7 @@ class SuspiciousTitForTat(Player):
 
     @staticmethod
     def strategy(opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         return C if opponent.history[-1:] == [C] else D
 
 
@@ -235,6 +246,7 @@ class AntiTitForTat(Player):
 
     @staticmethod
     def strategy(opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         return D if opponent.history[-1:] == [C] else C
 
 
@@ -258,6 +270,7 @@ class HardTitForTat(Player):
 
     @staticmethod
     def strategy(opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         # Cooperate on the first move
         if not opponent.history:
             return C
@@ -289,6 +302,7 @@ class HardTitFor2Tats(Player):
 
     @staticmethod
     def strategy(opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         # Cooperate on the first move
         if not opponent.history:
             return C
@@ -302,13 +316,13 @@ class HardTitFor2Tats(Player):
 
 class OmegaTFT(Player):
     """OmegaTFT modifies Tit For Tat in two ways:
-       - checks for deadlock loops of alternating rounds of (C, D) and (D, C),
-       and attempting to break them
-       - uses a more sophisticated retaliation mechanism that is noise tolerant
+    - checks for deadlock loops of alternating rounds of (C, D) and (D, C),
+    and attempting to break them
+    - uses a more sophisticated retaliation mechanism that is noise tolerant
 
-       Names:
+    Names:
 
-       - OmegaTFT: [Slany2007]_
+    - OmegaTFT: [Slany2007]_
     """
 
     name = "Omega TFT"
@@ -331,6 +345,7 @@ class OmegaTFT(Player):
         self.deadlock_counter = 0
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         # Cooperate on the first move
         if not self.history:
             return C
@@ -389,7 +404,7 @@ class OriginalGradual(Player):
     Names:
 
     - Gradual: [Beaufils1997]_
-     """
+    """
 
     name = "Original Gradual"
     classifier = {
@@ -410,6 +425,7 @@ class OriginalGradual(Player):
         self.punishment_limit = 0
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
 
         if self.calming:
             self.calming = False
@@ -475,6 +491,7 @@ class Gradual(Player):
         self.punish_count = 0
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
 
         if len(self.history) == 0:
             return C
@@ -523,6 +540,7 @@ class ContriteTitForTat(Player):
         self._recorded_history = []
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
 
         if not opponent.history:
             return C
@@ -590,6 +608,7 @@ class AdaptiveTitForTat(Player):
         self.world = rate
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
 
         if len(opponent.history) == 0:
             return C
@@ -631,6 +650,7 @@ class SpitefulTitForTat(Player):
         self.retaliating = False
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         # First move
         if not self.history:
             return C
@@ -668,6 +688,7 @@ class SlowTitForTwoTats2(Player):
     }
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
 
         # Start with two cooperations
         if len(self.history) < 2:
@@ -702,6 +723,7 @@ class Alexei(Player):
     }
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         if not self.history:
             return C
         if opponent.history[-1] == D:
@@ -736,6 +758,7 @@ class EugineNier(Player):
         self.is_defector = False
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         if not self.history:
             return C
         if not (self.is_defector) and opponent.defections >= 5:
@@ -791,6 +814,7 @@ class NTitsForMTats(Player):
         self.retaliate_count = 0
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         # if opponent defected consecutively M times, start the retaliation
         if not self.M or opponent.history[-self.M :].count(D) == self.M:
             self.retaliate_count = self.N
@@ -829,6 +853,7 @@ class Michaelos(Player):
         self.is_defector = False
 
     def strategy(self, opponent: Player) -> Action:
+        """Actual strategy definition that determines player's action."""
         if not self.history:
             return C
         if self.is_defector:
