@@ -33,7 +33,7 @@ class Tournament(object):
         noise: float = 0,
         edges: List[Tuple] = None,
         match_attributes: dict = None,
-        seed: int = None
+        seed: int = None,
     ) -> None:
         """
         Parameters
@@ -52,14 +52,15 @@ class Tournament(object):
             The number of times the round robin should be repeated
         noise : float
             The probability that a player's intended action should be flipped
-        prob_end : float
-            The probability of a given turn ending a match
         edges : list
             A list of edges between players
         match_attributes : dict
             Mapping attribute names to values which should be passed to players.
             The default is to use the correct values for turns, game and noise
             but these can be overridden if desired.
+        seed : integer
+            The seed for random numbers that will be generated for this
+            tournament, thus allowing future runs to exactly reproduce results.
         """
         if game is None:
             self.game = Game()
@@ -87,7 +88,7 @@ class Tournament(object):
             noise=self.noise,
             edges=edges,
             match_attributes=match_attributes,
-            seed=self.seed
+            seed=self.seed,
         )
         self._logger = logging.getLogger(__name__)
 
@@ -97,7 +98,7 @@ class Tournament(object):
 
     def setup_output(self, filename=None):
         """assign/create `filename` to `self`. If file should be deleted once
-        `play` is finished, assign a file descriptor. """
+        `play` is finished, assign a file descriptor."""
         temp_file_descriptor = None
         if filename is None:
             temp_file_descriptor, filename = mkstemp()
@@ -232,7 +233,9 @@ class Tournament(object):
 
     def _get_progress_bar(self):
         if self.use_progress_bar:
-            return tqdm.tqdm(total=self.match_generator.size, desc="Playing matches")
+            return tqdm.tqdm(
+                total=self.match_generator.size, desc="Playing matches"
+            )
         return None
 
     def _write_interactions_to_file(self, results, writer):
@@ -256,8 +259,14 @@ class Tournament(object):
                     ) = results
                 for index, player_index in enumerate(index_pair):
                     opponent_index = index_pair[index - 1]
-                    row = [self.num_interactions, player_index, opponent_index, repetition,
-                           str(self.players[player_index]), str(self.players[opponent_index])]
+                    row = [
+                        self.num_interactions,
+                        player_index,
+                        opponent_index,
+                        repetition,
+                        str(self.players[player_index]),
+                        str(self.players[opponent_index]),
+                    ]
                     history = actions_to_str([i[index] for i in interaction])
                     row.append(history)
 
@@ -277,16 +286,24 @@ class Tournament(object):
                         for state in states:
                             row.append(state_distribution[state])
                         for state in states:
-                            row.append(state_to_action_distributions[index][(state, C)])
-                            row.append(state_to_action_distributions[index][(state, D)])
+                            row.append(
+                                state_to_action_distributions[index][(state, C)]
+                            )
+                            row.append(
+                                state_to_action_distributions[index][(state, D)]
+                            )
 
-                        row.append(int(cooperations[index] >= cooperations[index - 1]))
+                        row.append(
+                            int(cooperations[index] >= cooperations[index - 1])
+                        )
 
                     writer.writerow(row)
                 repetition += 1
                 self.num_interactions += 1
 
-    def _run_parallel(self, processes: int = 2, build_results: bool = True) -> bool:
+    def _run_parallel(
+        self, processes: int = 2, build_results: bool = True
+    ) -> bool:
         """
         Run all matches in parallel
 
@@ -349,7 +366,8 @@ class Tournament(object):
         """
         for worker in range(workers):
             process = Process(
-                target=self._worker, args=(work_queue, done_queue, build_results)
+                target=self._worker,
+                args=(work_queue, done_queue, build_results),
             )
             work_queue.put("STOP")
             process.start()
@@ -387,7 +405,9 @@ class Tournament(object):
         _close_objects(out_file, progress_bar)
         return True
 
-    def _worker(self, work_queue: Queue, done_queue: Queue, build_results: bool = True):
+    def _worker(
+        self, work_queue: Queue, done_queue: Queue, build_results: bool = True
+    ):
         """
         The work for each parallel sub-process to execute.
 
@@ -455,13 +475,17 @@ class Tournament(object):
         turns = len(interactions)
         results.append(turns)
 
-        score_per_turns = iu.compute_final_score_per_turn(interactions, self.game)
+        score_per_turns = iu.compute_final_score_per_turn(
+            interactions, self.game
+        )
         results.append(score_per_turns)
 
         score_diffs_per_turns = score_diffs[0] / turns, score_diffs[1] / turns
         results.append(score_diffs_per_turns)
 
-        initial_coops = tuple(map(bool, iu.compute_cooperations(interactions[:1])))
+        initial_coops = tuple(
+            map(bool, iu.compute_cooperations(interactions[:1]))
+        )
         results.append(initial_coops)
 
         cooperations = iu.compute_cooperations(interactions)
